import { FastifyInstance, FastifyRequest, FastifyServerOptions } from 'fastify';
import { PubSubConfig, PubSubHandler } from '../types';
export interface PubSubServerConfig<Data, Context> extends Omit<PubSubConfig<Data, Context>, 'handler'> {
    /**
     * Will automatically pick up PORT environment variable.
     * @default 8000
     */
    port?: number;
    /**
     * @default 0.0.0.0
     */
    host?: string;
    /**
     * @default 0.0.0.0
     * @deprecated `address` will be removed in next major release. Please use `host` instead.
     */
    address?: string;
    /**
     * Read more here: https://www.fastify.io/docs/latest/Server/
     */
    fastifyConfig?: FastifyServerOptions;
}
export interface CreatePubSubHandlerResponse {
    listen: () => Promise<void>;
    fastify: FastifyInstance;
}
export declare function createPubSubServer<Data>(handler: PubSubHandler<Data, FastifyRequest>, config?: PubSubServerConfig<Data, FastifyRequest>): CreatePubSubHandlerResponse;
