import { Static } from '@sinclair/typebox';
import { FastifyBaseLogger } from 'fastify';
import pino from 'pino';
export interface PubSubConfig<Data, Context> {
    /**
     * Handler
     */
    handler: PubSubHandler<Data, Context>;
    /**
     * OnError Handler
     *
     * When this is set, errors will not be
     * thrown.
     */
    onError?: OnErrorHandler<Context>;
    parser?: (data: unknown) => Data | Promise<Data>;
    /**
     * This will run JSON.parse on request data
     *
     * **Tip**: `false` when sending strings
     * @default true
     */
    parseJson?: boolean;
    /**
     * Use this to set a different path
     * @default /
     */
    path?: string;
}
export declare const PubSubMessage: import("@sinclair/typebox").TObject<{
    attributes: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>>;
    data: import("@sinclair/typebox").TString;
    messageId: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export declare type PubSubMessageType = Static<typeof PubSubMessage>;
export declare const PubSubRequest: import("@sinclair/typebox").TObject<{
    message: import("@sinclair/typebox").TObject<{
        attributes: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>>;
        data: import("@sinclair/typebox").TString;
        messageId: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    }>;
    subscription: import("@sinclair/typebox").TString;
}>;
export declare type PubSubRequestType = Static<typeof PubSubRequest>;
export declare class PubSubHandlerResponse {
    statusCode?: number;
}
export declare type PubSubHandler<Data, Context> = (args: {
    message: PubSubMessageType;
    data: Data;
    context?: Context;
    log: FastifyBaseLogger;
}) => Promise<PubSubHandlerResponse | void> | PubSubHandlerResponse | void;
export declare type OnErrorHandler<Context> = (error: unknown, context: Context) => void | Promise<void>;
export interface HandlePubSubMessageArgs<Data, Context> {
    message: PubSubMessageType;
    handler: PubSubHandler<Data, Context>;
    parseJson?: boolean;
    parser?: (data: unknown) => Data | Promise<Data>;
    context: Context;
    log?: pino.Logger | FastifyBaseLogger;
}
